==> arquillian-protocol-servlet-1.1.12.Final-sources.jar: org/jboss/arquillian/protocol/servlet/Processor.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009 Red Hat Inc. and/or its affiliates and other contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.protocol.servlet;

import java.util.Collection;

import org.jboss.arquillian.container.test.spi.TestDeployment;
import org.jboss.arquillian.container.test.spi.client.deployment.ProtocolArchiveProcessor;
import org.jboss.shrinkwrap.api.Archive;

/**
 * Processor
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class Processor 
{
   private TestDeployment deployment;
   private Collection<ProtocolArchiveProcessor> processors;
   
   public Processor(TestDeployment deployment, Collection<ProtocolArchiveProcessor> processors)
   {
      this.deployment = deployment;
      this.processors = processors;
   }
   
   public void process(Archive<?> protocol)
   {
      for(ProtocolArchiveProcessor processor : processors)
      {
         processor.process(deployment, protocol);
      }
   }
}

==> arquillian-protocol-servlet-1.9.5.Final-sources.jar: org/jboss/arquillian/protocol/servlet/Processor.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009 Red Hat Inc. and/or its affiliates and other contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.protocol.servlet;

import java.util.Collection;
import org.jboss.arquillian.container.test.spi.TestDeployment;
import org.jboss.arquillian.container.test.spi.client.deployment.ProtocolArchiveProcessor;
import org.jboss.shrinkwrap.api.Archive;

/**
 * Processor
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 */
public class Processor {
    private TestDeployment deployment;
    private Collection<ProtocolArchiveProcessor> processors;

    public Processor(TestDeployment deployment, Collection<ProtocolArchiveProcessor> processors) {
        this.deployment = deployment;
        this.processors = processors;
    }

    public void process(Archive<?> protocol) {
        for (ProtocolArchiveProcessor processor : processors) {
            processor.process(deployment, protocol);
        }
    }
}
